export { singleLineFullQuery } from './queries/singleLineFullQuery.js';
export { singleLineFullQueryWithAggregation } from './queries/singleLineFullQueryWithAggregation.js';
export { multiLineFullQuery } from './queries/multiLineFullQuery.js';
export { multiLineFullQueryWithAggregation } from './queries/multiLineFullQueryWithAggregation.js';
export { singleLineEmptyQuery } from './queries/singleLineEmptyQuery.js';
export { singleLineTwoQueries } from './queries/singleLineTwoQueries.js';
export { singleLineTwoQueriesWithAggregation } from './queries/singleLineTwoQueriesWithAggregation.js';
export { singleLineMultipleColumns } from './queries/singleLineMultipleColumns.js';
export { multiLineMultipleColumns } from './queries/multiLineMultipleColumns.js';
//# sourceMappingURL=testData.js.map
