var QueryEditorPropertyType = /* @__PURE__ */ ((QueryEditorPropertyType2) => {
  QueryEditorPropertyType2["String"] = "string";
  return QueryEditorPropertyType2;
})(QueryEditorPropertyType || {});
var QueryEditorExpressionType = /* @__PURE__ */ ((QueryEditorExpressionType2) => {
  QueryEditorExpressionType2["Property"] = "property";
  QueryEditorExpressionType2["Operator"] = "operator";
  QueryEditorExpressionType2["Or"] = "or";
  QueryEditorExpressionType2["And"] = "and";
  QueryEditorExpressionType2["GroupBy"] = "groupBy";
  QueryEditorExpressionType2["Function"] = "function";
  QueryEditorExpressionType2["FunctionParameter"] = "functionParameter";
  return QueryEditorExpressionType2;
})(QueryEditorExpressionType || {});

export { QueryEditorExpressionType, QueryEditorPropertyType };
//# sourceMappingURL=expressions.js.map
