import { __exports as lite } from '../../../_virtual/index7.js';

var hasRequiredLite;

function requireLite () {
	if (hasRequiredLite) return lite;
	hasRequiredLite = 1;
	var has = Object.prototype.hasOwnProperty;

	function dequal(foo, bar) {
		var ctor, len;
		if (foo === bar) return true;

		if (foo && bar && (ctor=foo.constructor) === bar.constructor) {
			if (ctor === Date) return foo.getTime() === bar.getTime();
			if (ctor === RegExp) return foo.toString() === bar.toString();

			if (ctor === Array) {
				if ((len=foo.length) === bar.length) {
					while (len-- && dequal(foo[len], bar[len]));
				}
				return len === -1;
			}

			if (!ctor || typeof foo === 'object') {
				len = 0;
				for (ctor in foo) {
					if (has.call(foo, ctor) && ++len && !has.call(bar, ctor)) return false;
					if (!(ctor in bar) || !dequal(foo[ctor], bar[ctor])) return false;
				}
				return Object.keys(bar).length === len;
			}
		}

		return foo !== foo && bar !== bar;
	}

	lite.dequal = dequal;
	return lite;
}

export { requireLite as __require };
//# sourceMappingURL=index.js.map
