import { __exports as treeRole } from '../../../../../../_virtual/treeRole.js';

var hasRequiredTreeRole;

function requireTreeRole () {
	if (hasRequiredTreeRole) return treeRole;
	hasRequiredTreeRole = 1;

	Object.defineProperty(treeRole, "__esModule", {
	  value: true
	});
	treeRole.default = undefined;
	var treeRole$1 = {
	  abstract: false,
	  accessibleNameRequired: true,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-errormessage': null,
	    'aria-invalid': null,
	    'aria-multiselectable': null,
	    'aria-required': null,
	    'aria-orientation': 'vertical'
	  },
	  relatedConcepts: [],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [['treeitem', 'group'], ['treeitem']],
	  requiredProps: {},
	  superClass: [['roletype', 'widget', 'composite', 'select'], ['roletype', 'structure', 'section', 'group', 'select']]
	};
	var _default = treeRole$1;
	treeRole.default = _default;
	return treeRole;
}

export { requireTreeRole as __require };
//# sourceMappingURL=treeRole.js.map
