import { __exports as gridRole } from '../../../../../../_virtual/gridRole.js';

var hasRequiredGridRole;

function requireGridRole () {
	if (hasRequiredGridRole) return gridRole;
	hasRequiredGridRole = 1;

	Object.defineProperty(gridRole, "__esModule", {
	  value: true
	});
	gridRole.default = undefined;
	var gridRole$1 = {
	  abstract: false,
	  accessibleNameRequired: true,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-multiselectable': null,
	    'aria-readonly': null
	  },
	  relatedConcepts: [],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [['row'], ['row', 'rowgroup']],
	  requiredProps: {},
	  superClass: [['roletype', 'widget', 'composite'], ['roletype', 'structure', 'section', 'table']]
	};
	var _default = gridRole$1;
	gridRole.default = _default;
	return gridRole;
}

export { requireGridRole as __require };
//# sourceMappingURL=gridRole.js.map
