import { __exports as tableRole } from '../../../../../../_virtual/tableRole.js';

var hasRequiredTableRole;

function requireTableRole () {
	if (hasRequiredTableRole) return tableRole;
	hasRequiredTableRole = 1;

	Object.defineProperty(tableRole, "__esModule", {
	  value: true
	});
	tableRole.default = undefined;
	var tableRole$1 = {
	  abstract: false,
	  accessibleNameRequired: true,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-colcount': null,
	    'aria-rowcount': null
	  },
	  relatedConcepts: [{
	    concept: {
	      name: 'table'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [['row'], ['row', 'rowgroup']],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = tableRole$1;
	tableRole.default = _default;
	return tableRole;
}

export { requireTableRole as __require };
//# sourceMappingURL=tableRole.js.map
