import React from 'react';
import Months from './YearView/Months.js';
type YearViewProps = React.ComponentProps<typeof Months>;
/**
 * Displays a given year.
 */
declare const YearView: React.FC<YearViewProps>;
export default YearView;
