import type { Position } from 'css-box-model';
import type { DragImpact } from '../../types';

export interface PublicResult {
  clientSelection: Position;
  impact: DragImpact;
  scrollJumpRequest: Position | null;
}
