import React from 'react';
import Decades from './CenturyView/Decades.js';
type CenturyViewProps = React.ComponentProps<typeof Decades>;
/**
 * Displays a given century.
 */
declare const CenturyView: React.FC<CenturyViewProps>;
export default CenturyView;
