import { __exports as dialogRole } from '../../../../../../_virtual/dialogRole.js';

var hasRequiredDialogRole;

function requireDialogRole () {
	if (hasRequiredDialogRole) return dialogRole;
	hasRequiredDialogRole = 1;

	Object.defineProperty(dialogRole, "__esModule", {
	  value: true
	});
	dialogRole.default = undefined;
	var dialogRole$1 = {
	  abstract: false,
	  accessibleNameRequired: true,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [{
	    concept: {
	      name: 'dialog'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'window']]
	};
	var _default = dialogRole$1;
	dialogRole.default = _default;
	return dialogRole;
}

export { requireDialogRole as __require };
//# sourceMappingURL=dialogRole.js.map
