"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[1646],{71646(e){e.exports=JSON.parse('{"grafana-sql":{"components":{"confirm-modal":{"builder-mode":"Tryb konstruktora nie wy\u015Bwietla zmian wprowadzonych w\xA0kodzie. Konstruktor zapyta\u0144 wy\u015Bwietla ostatnie zmiany wprowadzone w\xA0trybie konstruktora.","cancel":"Anuluj","clipboard":"Czy chcesz skopiowa\u0107 kod do schowka?","copy-code-and-switch":"Skopiuj kod i\xA0prze\u0142\u0105cz","discard-code-and-switch":"Odrzu\u0107 kod i\xA0prze\u0142\u0105cz","warning":"Ostrze\u017Cenie"},"connection-limits":{"auto-max-idle":"Automatyczny maksymalny czas bezczynno\u015Bci","content-auto-max-idle":"","content-max-idle":"","content-max-lifetime":"Maksymalny czas w\xA0sekundach, przez kt\xF3ry po\u0142\u0105czenie mo\u017Ce by\u0107 ponownie u\u017Cyte. Je\u015Bli ustawiono warto\u015B\u0107\xA00, po\u0142\u0105czenia s\u0105 ponownie wykorzystywane bez daty zako\u0144czenia.","content-max-open":"","max-idle":"Maks. czas bezczynno\u015Bci","max-lifetime":"Maks. czas istnienia","max-open":"Maks. czas otwarcia","title-connection-limits":"Limity po\u0142\u0105cze\u0144"},"dataset-selector":{"aria-label-dataset-selector":"Selektor zbioru danych"},"error-boundary":{"fall-back":{"error":"B\u0142\u0105d"}},"get-custom-operators":{"custom-operators":{"label":{"macros":"Makra"}}},"make-render-column":{"render-column":{"aria-label-group-by":"Grupuj wed\u0142ug","title-remove-group-by-column":"Usu\u0144 grup\u0119 wed\u0142ug kolumny"}},"order-by-row":{"aria-label-order-by":"Kolejno\u015B\u0107 wed\u0142ug","label-limit":"Limit","label-offset":"Przesuni\u0119cie","label-order-by":"Kolejno\u015B\u0107 wed\u0142ug"},"preview":{"label-element":{"preview":"Podgl\u0105d","tooltip-copy-to-clipboard":"Kopiuj do schowka"}},"query-header":{"content-invalid-query":"","editor-modes":{"label-builder":"Konstruktor","label-code":"Kod"},"label-dataset":"Zbi\xF3r danych","label-filter":"Filtr","label-format":"Format","label-group":"Grupa","label-order":"Kolejno\u015B\u0107","label-preview":"Podgl\u0105d","label-table":"Tabela","placeholder-select-format":"Wybierz format","run-query":"Uruchom zapytanie"},"query-meta":{"variables":{"textField":"","valueField":""}},"query-toolbox":{"content-hit-ctrlcmdreturn-to-run-query":"Naci\u015Bnij CTRL/CMD\xA0+\xA0Return, aby uruchomi\u0107 zapytanie","tooltip-collapse":"Zwi\u0144 edytor","tooltip-expand":"Rozwi\u0144 edytor","tooltip-format-query":"Formatuj zapytanie"},"query-validator":{"query-will-process":"","validating-query":"Sprawdzanie poprawno\u015Bci zapytania\u2026"},"raw-editor":{"render-placeholder":{"editing-in-expanded-code-editor":"Edycja w\xA0rozszerzonym edytorze kodu"},"title-query-num":"Zapytanie {{queryNum}}"},"select-column":{"label-column":"Kolumna"},"select-custom-function-parameters":{"aria-label-parameter":"Parametr {{index}} dotycz\u0105cy kolumny {{columnIndex}}","render-parameters":{"params":{"title-remove-parameter":"Usu\u0144 parametr"}},"title-add-parameter":"Dodaj parametr"},"select-row":{"aggregate-options":{"options":{"label":{"aggregations":"Agregacje","macros":"Makra"}}},"label":{"time":"czas","value":"warto\u015B\u0107"},"label-alias":"Alias","label-data-operations":"Operacje na danych","title-add-column":"Dodaj kolumn\u0119","title-remove-column":"Usu\u0144 kolumn\u0119"},"settings":{"aria-label-conjunction":"Koniunkcja","aria-label-field":"Pole","aria-label-operator":"Operator","title-button-filter":"Filtr: {{ buttonLabel }}"},"sql-query-editor-lazy":{"text-loading-editor":"\u0141adowanie edytora\u2026"},"table-selector":{"aria-label-table-selector":"Selektor tabel","placeholder-loading":"\u0141adowanie tabel","placeholder-select-table":"Wybierz tabel\u0119"},"tlssecrets-config":{"content-tlsssl-client-certificate":"Aby uwierzytelni\u0107 si\u0119 za pomoc\u0105 certyfikatu klienta TLS/SSL, podaj tutaj certyfikat klienta.","content-tlsssl-client-key":"Aby uwierzytelni\u0107 si\u0119 za pomoc\u0105 certyfikatu klienta TLS/SSL, podaj tutaj klucz.","content-tlsssl-root-certificate":"Je\u015Bli wybrany tryb TLS/SSL wymaga certyfikatu g\u0142\xF3wnego serwera, podaj go tutaj","tlsssl-client-certificate":"Certyfikat klienta TLS/SSL","tlsssl-client-key":"Klucz TLS/SSL klienta","tlsssl-root-certificate":"Certyfikat g\u0142\xF3wny TLS/SSL"},"visual-editor":{"label-filter-by-column-value":"Filtruj wed\u0142ug warto\u015Bci kolumny","label-group-by-column":"Grupuj wg kolumny"},"widgets":{"aria-label-macros-value-selector":"Selektor warto\u015Bci makr"}},"utils":{"get-columns-width-indices":{"label-selected-columns":"Wybrane kolumny"}}}}')}}]);

//# sourceMappingURL=1646.1753a0f1a155cb88387c.js.map