"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[44],{31542(l,n,a){a.r(n),a.d(n,{default:()=>_});var r=a(74848),t=a(88547),s=a(36826),E=a(15784);function P(){return(0,r.jsx)(s.d,{navId:"alerts-history",isLoading:!1,children:(0,r.jsx)(E.CentralAlertHistoryScene,{})})}const _=(0,t.S)(P)}}]);

//# sourceMappingURL=HistoryPage.d2eee079ee7b2f2d2585.js.map