import { __exports as searchRole } from '../../../../../../_virtual/searchRole.js';

var hasRequiredSearchRole;

function requireSearchRole () {
	if (hasRequiredSearchRole) return searchRole;
	hasRequiredSearchRole = 1;

	Object.defineProperty(searchRole, "__esModule", {
	  value: true
	});
	searchRole.default = undefined;
	var searchRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section', 'landmark']]
	};
	var _default = searchRole$1;
	searchRole.default = _default;
	return searchRole;
}

export { requireSearchRole as __require };
//# sourceMappingURL=searchRole.js.map
