"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[9161],{19161(b,i,a){a.d(i,{$A:()=>l,Qx:()=>f,f5:()=>c});var u=a(2543),p=a.n(u);function l(n,r){return n.filter(e=>!r.find(t=>JSON.stringify(t)===JSON.stringify(e)))}function f(n){const r=n.flatMap(t=>t);return(0,u.uniqBy)(r.filter(t=>r.filter(s=>(0,u.isEqual)(t,s)).length===Object.keys(n).length),t=>JSON.stringify(t))}function c(n){if(!n?.data||!n.data.values||!Array.isArray(n.data.values))return[];const[r,e]=n.data.values;return!Array.isArray(r)||!Array.isArray(e)||r.length!==e.length?[]:(d(r)?r:[]).reduce((s,y,h)=>{const o=e[h];return m(o)&&s.push({timestamp:y,line:o}),s},[])}function d(n){return n.every(r=>typeof r=="number")}function m(n){return typeof n=="object"&&n!==null&&"current"in n&&"previous"in n}}}]);

//# sourceMappingURL=9161.be3fcb750f5bb1cbd522.js.map