export interface PlaceholderStyle {
  display: string;
  boxSizing: 'border-box';
  width: number;
  height: number;
  marginTop: number;
  marginRight: number;
  marginBottom: number;
  marginLeft: number;
  flexShrink: '0';
  flexGrow: '0';
  pointerEvents: 'none';
  transition: string;
}
