import { __exports as termRole } from '../../../../../../_virtual/termRole.js';

var hasRequiredTermRole;

function requireTermRole () {
	if (hasRequiredTermRole) return termRole;
	hasRequiredTermRole = 1;

	Object.defineProperty(termRole, "__esModule", {
	  value: true
	});
	termRole.default = undefined;
	var termRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [{
	    concept: {
	      name: 'dfn'
	    },
	    module: 'HTML'
	  }, {
	    concept: {
	      name: 'dt'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = termRole$1;
	termRole.default = _default;
	return termRole;
}

export { requireTermRole as __require };
//# sourceMappingURL=termRole.js.map
