import React from 'react';
import Years from './DecadeView/Years.js';
type DecadeViewProps = React.ComponentProps<typeof Years>;
/**
 * Displays a given decade.
 */
declare const DecadeView: React.FC<DecadeViewProps>;
export default DecadeView;
