import { __exports as timeRole } from '../../../../../../_virtual/timeRole.js';

var hasRequiredTimeRole;

function requireTimeRole () {
	if (hasRequiredTimeRole) return timeRole;
	hasRequiredTimeRole = 1;

	Object.defineProperty(timeRole, "__esModule", {
	  value: true
	});
	timeRole.default = undefined;
	var timeRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [{
	    concept: {
	      name: 'time'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = timeRole$1;
	timeRole.default = _default;
	return timeRole;
}

export { requireTimeRole as __require };
//# sourceMappingURL=timeRole.js.map
