import { jsxs, jsx } from 'react/jsx-runtime';

const QueryEditorRow = (props) => {
  var _a, _b;
  const className = (_a = props.className) != null ? _a : "width-8";
  const noFillEnd = (_b = props.noFillEnd) != null ? _b : false;
  return /* @__PURE__ */ jsxs("div", { className: "gf-form", children: [
    props.label && /* @__PURE__ */ jsx("label", { className: `gf-form-label query-keyword ${className}`, children: props.label }),
    props.children,
    /* @__PURE__ */ jsx("div", { className: "gf-form--grow", children: noFillEnd || /* @__PURE__ */ jsx("div", { className: "gf-form-label gf-form-label--grow" }) })
  ] });
};

export { QueryEditorRow };
//# sourceMappingURL=QueryEditorRow.js.map
