"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[3659],{33659(i,_,a){a.r(_),a.d(_,{default:()=>e});var t=a(74848),n=a(54078),r=a(35748);const e=({query:o})=>(0,t.jsx)("pre",{children:(0,t.jsx)(n.Z,{query:o,language:{grammar:r.n6,name:"promql"}})})},54078(i,_,a){a.d(_,{Z:()=>o});var t=a(74848),n=a(22803),r=a(28848),E=a(63704),e=a(63142);function o({query:s,language:l,className:P}){const g=(0,e.$j)(),h=m(g),u=r.highlight(s,l.grammar,l.name);return(0,t.jsx)("div",{className:(0,n.cx)(h.editorField,"prism-syntax-highlight",P),"aria-label":"selector",dangerouslySetInnerHTML:{__html:E.sQ.sanitize(u)}})}const m=s=>({editorField:(0,n.css)({fontFamily:s.typography.fontFamilyMonospace,fontSize:s.typography.bodySmall.fontSize})})}}]);

//# sourceMappingURL=3659.8a53f64a318a55d9a77d.js.map