import { __require as requireBuild } from '../node_modules/@testing-library/dom/node_modules/pretty-format/build/index.js';

var buildExports = requireBuild();

export { buildExports as b };
//# sourceMappingURL=index.js.map
