import sqlFormatter from 'sql-formatter-plus';

function formatSQL(q) {
  return sqlFormatter.format(q).replace(/(\$ \{ .* \})|(\$ __)|(\$ \w+)/g, (m) => {
    return m.replace(/\s/g, "");
  });
}

export { formatSQL };
//# sourceMappingURL=formatSQL.js.map
