"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[4113],{94113(e){e.exports=JSON.parse('{"grafana-sql":{"components":{"confirm-modal":{"builder-mode":"Byggl\xE4ge visar inte \xE4ndringar gjorda i koden. Fr\xE5gebyggaren visar de senaste \xE4ndringarna du gjorde i byggl\xE4get.","cancel":"Avbryt","clipboard":"Vill du kopiera din kod till urklippet?","copy-code-and-switch":"Kopiera kod och v\xE4xla","discard-code-and-switch":"Kassera kod och v\xE4xla","warning":"Varning"},"connection-limits":{"auto-max-idle":"Automatisk max. inaktiv","content-auto-max-idle":"","content-max-idle":"","content-max-lifetime":"Den maximala tiden i sekunder som en anslutning kan \xE5teranv\xE4ndas. Om inst\xE4llningen \xE4r 0 \xE5teranv\xE4nds anslutningarna f\xF6r evigt.","content-max-open":"","max-idle":"Max inaktiv","max-lifetime":"Max livstid","max-open":"Max \xF6ppen","title-connection-limits":"Anslutningsbegr\xE4nsningar"},"dataset-selector":{"aria-label-dataset-selector":"Dataupps\xE4ttningsv\xE4ljare"},"error-boundary":{"fall-back":{"error":"Fel"}},"get-custom-operators":{"custom-operators":{"label":{"macros":"Makron"}}},"make-render-column":{"render-column":{"aria-label-group-by":"Gruppera efter","title-remove-group-by-column":"Ta bort gruppen efter kolumn"}},"order-by-row":{"aria-label-order-by":"Sortera efter","label-limit":"Gr\xE4ns","label-offset":"F\xF6rskjutning","label-order-by":"Sortera efter"},"preview":{"label-element":{"preview":"F\xF6rhandsgranska","tooltip-copy-to-clipboard":"Kopiera till urklippet"}},"query-header":{"content-invalid-query":"","editor-modes":{"label-builder":"Builder","label-code":"Kod"},"label-dataset":"Dataupps\xE4ttning","label-filter":"Filtrera","label-format":"Format","label-group":"Grupp","label-order":"Best\xE4llning","label-preview":"F\xF6rhandsgranska","label-table":"Tabell","placeholder-select-format":"V\xE4lj format","run-query":"K\xF6r fr\xE5ga"},"query-meta":{"variables":{"textField":"","valueField":""}},"query-toolbox":{"content-hit-ctrlcmdreturn-to-run-query":"Tryck p\xE5 CTRL/CMD+Retur f\xF6r att k\xF6ra fr\xE5gan","tooltip-collapse":"Minimera redigeraren","tooltip-expand":"Expandera redigeraren","tooltip-format-query":"Formatera fr\xE5ga"},"query-validator":{"query-will-process":"","validating-query":"Validerar fr\xE5gan\xA0\u2026"},"raw-editor":{"render-placeholder":{"editing-in-expanded-code-editor":"Redigering i expanderad kodredigerare"},"title-query-num":"Fr\xE5ga {{queryNum}}"},"select-column":{"label-column":"Kolumn"},"select-custom-function-parameters":{"aria-label-parameter":"Parameter {{index}} f\xF6r kolumnen {{columnIndex}}","render-parameters":{"params":{"title-remove-parameter":"Ta bort parameter"}},"title-add-parameter":"L\xE4gg till parameter"},"select-row":{"aggregate-options":{"options":{"label":{"aggregations":"Aggregeringar","macros":"Makron"}}},"label":{"time":"tid","value":"v\xE4rde"},"label-alias":"Alias","label-data-operations":"Data\xE5tg\xE4rder","title-add-column":"L\xE4gg till kolumn","title-remove-column":"Ta bort kolumn"},"settings":{"aria-label-conjunction":"Konjunktion","aria-label-field":"F\xE4lt","aria-label-operator":"Operat\xF6r","title-button-filter":"{{ buttonLabel }} filter"},"sql-query-editor-lazy":{"text-loading-editor":"Laddar redigerare"},"table-selector":{"aria-label-table-selector":"Tabellv\xE4ljare","placeholder-loading":"Laddar tabeller","placeholder-select-table":"V\xE4lj tabell"},"tlssecrets-config":{"content-tlsssl-client-certificate":"F\xF6r autentisering med ett TLS-/SSL-klientcertifikat anger du klientcertifikatet h\xE4r.","content-tlsssl-client-key":"F\xF6r autentisering med ett TLS-/SSL-klientcertifikat anger du nyckeln h\xE4r.","content-tlsssl-root-certificate":"Om det valda TLS-/SSL-l\xE4get kr\xE4ver ett serverrotcertifikat anger du det h\xE4r","tlsssl-client-certificate":"TLS-/SSL-klientcertifikat","tlsssl-client-key":"TLS/SSL-klientnyckel","tlsssl-root-certificate":"TLS-/SSL-rotcertifikat"},"visual-editor":{"label-filter-by-column-value":"Filtrera efter kolumnv\xE4rde","label-group-by-column":"Gruppera efter kolumn"},"widgets":{"aria-label-macros-value-selector":"Makrov\xE4rdesv\xE4ljare"}},"utils":{"get-columns-width-indices":{"label-selected-columns":"Valda kolumner"}}}}')}}]);

//# sourceMappingURL=4113.5768342333f79284014d.js.map