import { __exports as statusRole } from '../../../../../../_virtual/statusRole.js';

var hasRequiredStatusRole;

function requireStatusRole () {
	if (hasRequiredStatusRole) return statusRole;
	hasRequiredStatusRole = 1;

	Object.defineProperty(statusRole, "__esModule", {
	  value: true
	});
	statusRole.default = undefined;
	var statusRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-atomic': 'true',
	    'aria-live': 'polite'
	  },
	  relatedConcepts: [{
	    concept: {
	      name: 'output'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = statusRole$1;
	statusRole.default = _default;
	return statusRole;
}

export { requireStatusRole as __require };
//# sourceMappingURL=statusRole.js.map
