import { getConfig } from '../../../../dom/dist/@testing-library/dom.esm.js';

/**
 * Wrap an internal Promise
 */ function wrapAsync(implementation) {
    return getConfig().asyncWrapper(implementation);
}

export { wrapAsync };
//# sourceMappingURL=wrapAsync.js.map
