export declare const formatDate: (locale: string | undefined, date: Date) => string;
export declare const formatDay: (locale: string | undefined, date: Date) => string;
export declare const formatLongDate: (locale: string | undefined, date: Date) => string;
export declare const formatMonth: (locale: string | undefined, date: Date) => string;
export declare const formatMonthYear: (locale: string | undefined, date: Date) => string;
export declare const formatShortWeekday: (locale: string | undefined, date: Date) => string;
export declare const formatWeekday: (locale: string | undefined, date: Date) => string;
export declare const formatYear: (locale: string | undefined, date: Date) => string;
