import { __exports as windowRole } from '../../../../../../_virtual/windowRole.js';

var hasRequiredWindowRole;

function requireWindowRole () {
	if (hasRequiredWindowRole) return windowRole;
	hasRequiredWindowRole = 1;

	Object.defineProperty(windowRole, "__esModule", {
	  value: true
	});
	windowRole.default = undefined;
	var windowRole$1 = {
	  abstract: true,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-modal': null
	  },
	  relatedConcepts: [],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype']]
	};
	var _default = windowRole$1;
	windowRole.default = _default;
	return windowRole;
}

export { requireWindowRole as __require };
//# sourceMappingURL=windowRole.js.map
