"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[1037],{90886(i,t,n){n.r(t),n.d(t,{default:()=>l});var a=n(74848),e=n(92745),r=n(34999),o=n(89640),_=n(66404),g=n(41654),s=n(13791),E=n(89315),d=n(37172);function l({items:P}){return(0,a.jsx)(s.Y,{navId:"provisioning",subTitle:(0,e.t)("provisioning.getting-started-page.subtitle-provisioning-feature","View and manage your provisioning connections"),children:(0,a.jsx)(s.Y.Contents,{children:(0,a.jsxs)(g.B,{direction:"column",gap:3,children:[(0,a.jsx)(u,{}),(0,a.jsx)(d.A,{items:P})]})})})}function u(){return(0,E.o)()?(0,a.jsx)(r.F,{severity:"info",title:"",children:(0,a.jsx)(_.E,{children:(0,a.jsxs)(e.x6,{i18nKey:"provisioning.banner.message",children:["This feature is currently under active development. For the best experience and latest improvements, we recommend using the"," ",(0,a.jsx)(o.Y,{href:"https://grafana.com/grafana/download/nightly",external:!0,children:"nightly build"})," ","of Grafana."]})})}):null}},88552(i,t,n){i.exports=n.p+"static/img/provisioning.d25529e1.svg"}}]);

//# sourceMappingURL=GettingStartedPage.0cff5e50d40c5ab0ab5a.js.map