import { __exports as logRole } from '../../../../../../_virtual/logRole.js';

var hasRequiredLogRole;

function requireLogRole () {
	if (hasRequiredLogRole) return logRole;
	hasRequiredLogRole = 1;

	Object.defineProperty(logRole, "__esModule", {
	  value: true
	});
	logRole.default = undefined;
	var logRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-live': 'polite'
	  },
	  relatedConcepts: [],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = logRole$1;
	logRole.default = _default;
	return logRole;
}

export { requireLogRole as __require };
//# sourceMappingURL=logRole.js.map
