import { getConfig } from '../../../../dom/dist/@testing-library/dom.esm.js';

function wrapEvent(cb, _element) {
    return getConfig().eventWrapper(cb);
}

export { wrapEvent };
//# sourceMappingURL=wrapEvent.js.map
