import { __exports as meterRole } from '../../../../../../_virtual/meterRole.js';

var hasRequiredMeterRole;

function requireMeterRole () {
	if (hasRequiredMeterRole) return meterRole;
	hasRequiredMeterRole = 1;

	Object.defineProperty(meterRole, "__esModule", {
	  value: true
	});
	meterRole.default = undefined;
	var meterRole$1 = {
	  abstract: false,
	  accessibleNameRequired: true,
	  baseConcepts: [],
	  childrenPresentational: true,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-valuetext': null,
	    'aria-valuemax': '100',
	    'aria-valuemin': '0'
	  },
	  relatedConcepts: [{
	    concept: {
	      name: 'meter'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {
	    'aria-valuenow': null
	  },
	  superClass: [['roletype', 'structure', 'range']]
	};
	var _default = meterRole$1;
	meterRole.default = _default;
	return meterRole;
}

export { requireMeterRole as __require };
//# sourceMappingURL=meterRole.js.map
