import { __exports as blockquoteRole } from '../../../../../../_virtual/blockquoteRole.js';

var hasRequiredBlockquoteRole;

function requireBlockquoteRole () {
	if (hasRequiredBlockquoteRole) return blockquoteRole;
	hasRequiredBlockquoteRole = 1;

	Object.defineProperty(blockquoteRole, "__esModule", {
	  value: true
	});
	blockquoteRole.default = undefined;
	var blockquoteRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [{
	    concept: {
	      name: 'blockquote'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = blockquoteRole$1;
	blockquoteRole.default = _default;
	return blockquoteRole;
}

export { requireBlockquoteRole as __require };
//# sourceMappingURL=blockquoteRole.js.map
