import React from 'react';
import type { ReactReduxContextValue } from 'react-redux';
import type { Action } from '../../state/store-types';
import type { State } from '../../types';

type StoreContextValue = ReactReduxContextValue<State, Action>;

export default React.createContext<StoreContextValue | null>(null);
