export declare const CALENDAR_TYPES: {
    readonly GREGORY: "gregory";
    readonly HEBREW: "hebrew";
    readonly ISLAMIC: "islamic";
    readonly ISO_8601: "iso8601";
};
export declare const DEPRECATED_CALENDAR_TYPES: {
    readonly ARABIC: "Arabic";
    readonly HEBREW: "Hebrew";
    readonly ISO_8601: "ISO 8601";
    readonly US: "US";
};
export declare const CALENDAR_TYPE_LOCALES: {
    gregory: string[];
    hebrew: string[];
    islamic: string[];
};
export declare const WEEKDAYS: readonly [0, 1, 2, 3, 4, 5, 6];
