import { __exports as articleRole } from '../../../../../../_virtual/articleRole.js';

var hasRequiredArticleRole;

function requireArticleRole () {
	if (hasRequiredArticleRole) return articleRole;
	hasRequiredArticleRole = 1;

	Object.defineProperty(articleRole, "__esModule", {
	  value: true
	});
	articleRole.default = undefined;
	var articleRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-posinset': null,
	    'aria-setsize': null
	  },
	  relatedConcepts: [{
	    concept: {
	      name: 'article'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'document']]
	};
	var _default = articleRole$1;
	articleRole.default = _default;
	return articleRole;
}

export { requireArticleRole as __require };
//# sourceMappingURL=articleRole.js.map
