import { __exports as timerRole } from '../../../../../../_virtual/timerRole.js';

var hasRequiredTimerRole;

function requireTimerRole () {
	if (hasRequiredTimerRole) return timerRole;
	hasRequiredTimerRole = 1;

	Object.defineProperty(timerRole, "__esModule", {
	  value: true
	});
	timerRole.default = undefined;
	var timerRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section', 'status']]
	};
	var _default = timerRole$1;
	timerRole.default = _default;
	return timerRole;
}

export { requireTimerRole as __require };
//# sourceMappingURL=timerRole.js.map
