"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[4964],{24964(e,_,a){a.r(_),a.d(_,{default:()=>o});var n=a(74848),t=a(54078),r=a(77236);const o=({query:l})=>(0,n.jsx)("pre",{children:(0,n.jsx)(t.Z,{query:l,language:{grammar:r.Ay,name:"promql"}})})},54078(e,_,a){a.d(_,{Z:()=>l});var n=a(74848),t=a(22803),r=a(28848),E=a(63704),o=a(63142);function l({query:s,language:i,className:g}){const m=(0,o.$j)(),d=P(m),M=r.highlight(s,i.grammar,i.name);return(0,n.jsx)("div",{className:(0,t.cx)(d.editorField,"prism-syntax-highlight",g),"aria-label":"selector",dangerouslySetInnerHTML:{__html:E.sQ.sanitize(M)}})}const P=s=>({editorField:(0,t.css)({fontFamily:s.typography.fontFamilyMonospace,fontSize:s.typography.bodySmall.fontSize})})}}]);

//# sourceMappingURL=4964.6a084adbffb47d78892f.js.map