import { __exports as marqueeRole } from '../../../../../../_virtual/marqueeRole.js';

var hasRequiredMarqueeRole;

function requireMarqueeRole () {
	if (hasRequiredMarqueeRole) return marqueeRole;
	hasRequiredMarqueeRole = 1;

	Object.defineProperty(marqueeRole, "__esModule", {
	  value: true
	});
	marqueeRole.default = undefined;
	var marqueeRole$1 = {
	  abstract: false,
	  accessibleNameRequired: true,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = marqueeRole$1;
	marqueeRole.default = _default;
	return marqueeRole;
}

export { requireMarqueeRole as __require };
//# sourceMappingURL=marqueeRole.js.map
