import { __exports as ariaDpubRoles } from '../../../../../_virtual/ariaDpubRoles.js';
import { __require as requireDocAbstractRole } from './dpub/docAbstractRole.js';
import { __require as requireDocAcknowledgmentsRole } from './dpub/docAcknowledgmentsRole.js';
import { __require as requireDocAfterwordRole } from './dpub/docAfterwordRole.js';
import { __require as requireDocAppendixRole } from './dpub/docAppendixRole.js';
import { __require as requireDocBacklinkRole } from './dpub/docBacklinkRole.js';
import { __require as requireDocBiblioentryRole } from './dpub/docBiblioentryRole.js';
import { __require as requireDocBibliographyRole } from './dpub/docBibliographyRole.js';
import { __require as requireDocBibliorefRole } from './dpub/docBibliorefRole.js';
import { __require as requireDocChapterRole } from './dpub/docChapterRole.js';
import { __require as requireDocColophonRole } from './dpub/docColophonRole.js';
import { __require as requireDocConclusionRole } from './dpub/docConclusionRole.js';
import { __require as requireDocCoverRole } from './dpub/docCoverRole.js';
import { __require as requireDocCreditRole } from './dpub/docCreditRole.js';
import { __require as requireDocCreditsRole } from './dpub/docCreditsRole.js';
import { __require as requireDocDedicationRole } from './dpub/docDedicationRole.js';
import { __require as requireDocEndnoteRole } from './dpub/docEndnoteRole.js';
import { __require as requireDocEndnotesRole } from './dpub/docEndnotesRole.js';
import { __require as requireDocEpigraphRole } from './dpub/docEpigraphRole.js';
import { __require as requireDocEpilogueRole } from './dpub/docEpilogueRole.js';
import { __require as requireDocErrataRole } from './dpub/docErrataRole.js';
import { __require as requireDocExampleRole } from './dpub/docExampleRole.js';
import { __require as requireDocFootnoteRole } from './dpub/docFootnoteRole.js';
import { __require as requireDocForewordRole } from './dpub/docForewordRole.js';
import { __require as requireDocGlossaryRole } from './dpub/docGlossaryRole.js';
import { __require as requireDocGlossrefRole } from './dpub/docGlossrefRole.js';
import { __require as requireDocIndexRole } from './dpub/docIndexRole.js';
import { __require as requireDocIntroductionRole } from './dpub/docIntroductionRole.js';
import { __require as requireDocNoterefRole } from './dpub/docNoterefRole.js';
import { __require as requireDocNoticeRole } from './dpub/docNoticeRole.js';
import { __require as requireDocPagebreakRole } from './dpub/docPagebreakRole.js';
import { __require as requireDocPagelistRole } from './dpub/docPagelistRole.js';
import { __require as requireDocPartRole } from './dpub/docPartRole.js';
import { __require as requireDocPrefaceRole } from './dpub/docPrefaceRole.js';
import { __require as requireDocPrologueRole } from './dpub/docPrologueRole.js';
import { __require as requireDocPullquoteRole } from './dpub/docPullquoteRole.js';
import { __require as requireDocQnaRole } from './dpub/docQnaRole.js';
import { __require as requireDocSubtitleRole } from './dpub/docSubtitleRole.js';
import { __require as requireDocTipRole } from './dpub/docTipRole.js';
import { __require as requireDocTocRole } from './dpub/docTocRole.js';

var hasRequiredAriaDpubRoles;

function requireAriaDpubRoles () {
	if (hasRequiredAriaDpubRoles) return ariaDpubRoles;
	hasRequiredAriaDpubRoles = 1;

	Object.defineProperty(ariaDpubRoles, "__esModule", {
	  value: true
	});
	ariaDpubRoles.default = undefined;
	var _docAbstractRole = _interopRequireDefault(requireDocAbstractRole());
	var _docAcknowledgmentsRole = _interopRequireDefault(requireDocAcknowledgmentsRole());
	var _docAfterwordRole = _interopRequireDefault(requireDocAfterwordRole());
	var _docAppendixRole = _interopRequireDefault(requireDocAppendixRole());
	var _docBacklinkRole = _interopRequireDefault(requireDocBacklinkRole());
	var _docBiblioentryRole = _interopRequireDefault(requireDocBiblioentryRole());
	var _docBibliographyRole = _interopRequireDefault(requireDocBibliographyRole());
	var _docBibliorefRole = _interopRequireDefault(requireDocBibliorefRole());
	var _docChapterRole = _interopRequireDefault(requireDocChapterRole());
	var _docColophonRole = _interopRequireDefault(requireDocColophonRole());
	var _docConclusionRole = _interopRequireDefault(requireDocConclusionRole());
	var _docCoverRole = _interopRequireDefault(requireDocCoverRole());
	var _docCreditRole = _interopRequireDefault(requireDocCreditRole());
	var _docCreditsRole = _interopRequireDefault(requireDocCreditsRole());
	var _docDedicationRole = _interopRequireDefault(requireDocDedicationRole());
	var _docEndnoteRole = _interopRequireDefault(requireDocEndnoteRole());
	var _docEndnotesRole = _interopRequireDefault(requireDocEndnotesRole());
	var _docEpigraphRole = _interopRequireDefault(requireDocEpigraphRole());
	var _docEpilogueRole = _interopRequireDefault(requireDocEpilogueRole());
	var _docErrataRole = _interopRequireDefault(requireDocErrataRole());
	var _docExampleRole = _interopRequireDefault(requireDocExampleRole());
	var _docFootnoteRole = _interopRequireDefault(requireDocFootnoteRole());
	var _docForewordRole = _interopRequireDefault(requireDocForewordRole());
	var _docGlossaryRole = _interopRequireDefault(requireDocGlossaryRole());
	var _docGlossrefRole = _interopRequireDefault(requireDocGlossrefRole());
	var _docIndexRole = _interopRequireDefault(requireDocIndexRole());
	var _docIntroductionRole = _interopRequireDefault(requireDocIntroductionRole());
	var _docNoterefRole = _interopRequireDefault(requireDocNoterefRole());
	var _docNoticeRole = _interopRequireDefault(requireDocNoticeRole());
	var _docPagebreakRole = _interopRequireDefault(requireDocPagebreakRole());
	var _docPagelistRole = _interopRequireDefault(requireDocPagelistRole());
	var _docPartRole = _interopRequireDefault(requireDocPartRole());
	var _docPrefaceRole = _interopRequireDefault(requireDocPrefaceRole());
	var _docPrologueRole = _interopRequireDefault(requireDocPrologueRole());
	var _docPullquoteRole = _interopRequireDefault(requireDocPullquoteRole());
	var _docQnaRole = _interopRequireDefault(requireDocQnaRole());
	var _docSubtitleRole = _interopRequireDefault(requireDocSubtitleRole());
	var _docTipRole = _interopRequireDefault(requireDocTipRole());
	var _docTocRole = _interopRequireDefault(requireDocTocRole());
	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var ariaDpubRoles$1 = [['doc-abstract', _docAbstractRole.default], ['doc-acknowledgments', _docAcknowledgmentsRole.default], ['doc-afterword', _docAfterwordRole.default], ['doc-appendix', _docAppendixRole.default], ['doc-backlink', _docBacklinkRole.default], ['doc-biblioentry', _docBiblioentryRole.default], ['doc-bibliography', _docBibliographyRole.default], ['doc-biblioref', _docBibliorefRole.default], ['doc-chapter', _docChapterRole.default], ['doc-colophon', _docColophonRole.default], ['doc-conclusion', _docConclusionRole.default], ['doc-cover', _docCoverRole.default], ['doc-credit', _docCreditRole.default], ['doc-credits', _docCreditsRole.default], ['doc-dedication', _docDedicationRole.default], ['doc-endnote', _docEndnoteRole.default], ['doc-endnotes', _docEndnotesRole.default], ['doc-epigraph', _docEpigraphRole.default], ['doc-epilogue', _docEpilogueRole.default], ['doc-errata', _docErrataRole.default], ['doc-example', _docExampleRole.default], ['doc-footnote', _docFootnoteRole.default], ['doc-foreword', _docForewordRole.default], ['doc-glossary', _docGlossaryRole.default], ['doc-glossref', _docGlossrefRole.default], ['doc-index', _docIndexRole.default], ['doc-introduction', _docIntroductionRole.default], ['doc-noteref', _docNoterefRole.default], ['doc-notice', _docNoticeRole.default], ['doc-pagebreak', _docPagebreakRole.default], ['doc-pagelist', _docPagelistRole.default], ['doc-part', _docPartRole.default], ['doc-preface', _docPrefaceRole.default], ['doc-prologue', _docPrologueRole.default], ['doc-pullquote', _docPullquoteRole.default], ['doc-qna', _docQnaRole.default], ['doc-subtitle', _docSubtitleRole.default], ['doc-tip', _docTipRole.default], ['doc-toc', _docTocRole.default]];
	var _default = ariaDpubRoles$1;
	ariaDpubRoles.default = _default;
	return ariaDpubRoles;
}

export { requireAriaDpubRoles as __require };
//# sourceMappingURL=ariaDpubRoles.js.map
