import { __exports as mainRole } from '../../../../../../_virtual/mainRole.js';

var hasRequiredMainRole;

function requireMainRole () {
	if (hasRequiredMainRole) return mainRole;
	hasRequiredMainRole = 1;

	Object.defineProperty(mainRole, "__esModule", {
	  value: true
	});
	mainRole.default = undefined;
	var mainRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [{
	    concept: {
	      name: 'main'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section', 'landmark']]
	};
	var _default = mainRole$1;
	mainRole.default = _default;
	return mainRole;
}

export { requireMainRole as __require };
//# sourceMappingURL=mainRole.js.map
