"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[7891],{31879(e,t,s){s.r(t),s.d(t,{default:()=>o});var p=s(74848),_=s(54148),a=s(68789);function o(){const{pluginId:c=""}=(0,_.g)();return(0,p.jsx)(a.V,{pluginId:c})}},14552(e,t,s){e.exports=s.p+"static/img/adobe-analytics.4753db26.svg"},42965(e,t,s){e.exports=s.p+"static/img/appdynamics.26e3d55b.svg"},63340(e,t,s){e.exports=s.p+"static/img/atlassian-statuspage.3c87e280.svg"},19810(e,t,s){e.exports=s.p+"static/img/aurora.b26d603d.svg"},36654(e,t,s){e.exports=s.p+"static/img/azure-cosmosdb.573a2a46.svg"},15912(e,t,s){e.exports=s.p+"static/img/azure-devops.a937d73a.png"},91735(e,t,s){e.exports=s.p+"static/img/catchpoint.fa6c7933.svg"},95552(e,t,s){e.exports=s.p+"static/img/cloudflare.ea4404be.jpg"},74484(e,t,s){e.exports=s.p+"static/img/cockroachdb.c40db97d.jpg"},51147(e,t,s){e.exports=s.p+"static/img/datadog.68935496.png"},79886(e,t,s){e.exports=s.p+"static/img/db2.673fad37.svg"},7672(e,t,s){e.exports=s.p+"static/img/drone.e55e0d85.svg"},36404(e,t,s){e.exports=s.p+"static/img/dynatrace.3510a47f.png"},70535(e,t,s){e.exports=s.p+"static/img/gitlab.a9ff2a14.svg"},23735(e,t,s){e.exports=s.p+"static/img/honeycomb.23074f0a.png"},26871(e,t,s){e.exports=s.p+"static/img/jira_logo.fc367bdf.png"},57454(e,t,s){e.exports=s.p+"static/img/logicmonitor.a0d2ddd9.svg"},10128(e,t,s){e.exports=s.p+"static/img/mongodb.cd31e197.svg"},78485(e,t,s){e.exports=s.p+"static/img/netlify.35f83f3c.svg"},59161(e,t,s){e.exports=s.p+"static/img/newrelic.4ba92509.svg"},69443(e,t,s){e.exports=s.p+"static/img/oracle.b53d3bc4.png"},94443(e,t,s){e.exports=s.p+"static/img/pagerduty.261221ea.svg"},12680(e,t,s){e.exports=s.p+"static/img/salesforce.f79d37a9.svg"},99444(e,t,s){e.exports=s.p+"static/img/sap_hana.7f369d20.png"},57925(e,t,s){e.exports=s.p+"static/img/servicenow.de3a7a6a.svg"},15584(e,t,s){e.exports=s.p+"static/img/signalfx-logo.70e37f3d.svg"},22810(e,t,s){e.exports=s.p+"static/img/snowflake.4951e616.svg"},73946(e,t,s){e.exports=s.p+"static/img/solarWinds.fe97cd47.svg"},42166(e,t,s){e.exports=s.p+"static/img/splunk_logo_128.08e4871b.png"},6758(e,t,s){e.exports=s.p+"static/img/sumo.3e01fb77.svg"},40250(e,t,s){e.exports=s.p+"static/img/wavefront.a8880e4a.svg"},16926(e,t,s){e.exports=s.p+"static/img/zendesk.9a6bf432.svg"}}]);

//# sourceMappingURL=PluginPage.c62394c4b53ba32e3945.js.map