"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[3804],{26200(T,a,t){t.r(a),t.d(a,{default:()=>p});var e=t(74848),s=t(54148),o=t(92745),l=t(34999),c=t(22628),u=t(88547),d=t(36826),g=t(41654),v=t(45861),f=t(66404),h=t(39187);const m=({name:n,returnToFallback:r})=>{const{returnTo:i}=(0,h.h)(r);return(0,e.jsxs)(g.B,{direction:"row",gap:1,minWidth:0,alignItems:"center",children:[(0,e.jsx)(v.z9,{"aria-label":(0,o.t)("alerting.title.aria-label-return-to","Return to previous view"),variant:"secondary",icon:"angle-left",href:i}),(0,e.jsx)(f.E,{element:"h1",truncate:!0,children:n})]})};var x=t(83605);const y=()=>{const{name:n=""}=(0,s.g)(),r=decodeURIComponent(n);return r?(0,e.jsx)(x.X,{routeName:r}):(0,e.jsx)(l.F,{severity:"error",title:(0,o.t)("alerting.policies-tree-wrapper.title-routing-tree-not-found","Routing tree not found"),children:(0,e.jsx)(o.x6,{i18nKey:"alerting.policies-tree-wrapper.sorry-routing-exist",children:"Sorry, this routing tree does not seem to exist."})})};function j(){const{name:n=""}=(0,s.g)(),r=n===c.DM?"Default Policy":decodeURIComponent(n);return(0,e.jsx)(d.y,{navId:"am-routes",accessType:"notification",pageNav:{text:r},renderTitle:i=>(0,e.jsx)(m,{name:i,returnToFallback:"/alerting/routes"}),subTitle:(0,o.t)("alerting.policy-page.text-subtitle","Determine how alerts are routed to contact points for alert rules configured to use this notification policy."),children:(0,e.jsx)(y,{})})}const p=(0,u.S)(j)}}]);

//# sourceMappingURL=PolicyPage.a370415efaf42e4e24c7.js.map