import '@grafana/data';
import { c as chanceExports } from '../../_virtual/chance.js';
import { undefinedOr } from './utils.js';

const mockDataQuery = () => ({
  refId: chanceExports.Chance().word(),
  hide: false,
  key: chanceExports.Chance().guid(),
  queryType: chanceExports.Chance().word(),
  datasource: undefinedOr(() => chanceExports.Chance().word())
});

export { mockDataQuery };
//# sourceMappingURL=DataQuery.js.map
