import * as testData from '../mocks/testData.js';
import { testStatementPosition } from './statementPosition.js';
import '@grafana/ui';

const SQLEditorTestUtils = {
  testData,
  testStatementPosition
};

export { SQLEditorTestUtils };
//# sourceMappingURL=index.js.map
