"use strict";(globalThis.webpackChunkmysql=globalThis.webpackChunkmysql||[]).push([[450],{5450(e){e.exports=JSON.parse('{"grafana-sql":{"components":{"confirm-modal":{"builder-mode":"Le mode Créateur n’affiche pas les modifications apportées au code. Le créateur de requêtes affichera les dernières modifications que vous avez apportées en mode Créateur.","cancel":"Annuler","clipboard":"Voulez-vous copier votre code dans le presse-papiers ?","copy-code-and-switch":"Copier le code et changer","discard-code-and-switch":"Ignorer le code et changer","warning":"Avertissement"},"connection-limits":{"auto-max-idle":"Inactivité maximale automatique","content-auto-max-idle":"","content-max-idle":"","content-max-lifetime":"La durée maximale en secondes pendant laquelle une connexion peut être réutilisée. Si la valeur est 0, les connexions sont réutilisées pour toujours.","content-max-open":"","max-idle":"Inactivité maximale","max-lifetime":"Durée de vie maximale","max-open":"Ouverture maximale","title-connection-limits":"Limites de connexion"},"dataset-selector":{"aria-label-dataset-selector":"Sélecteur d’ensemble de données"},"error-boundary":{"fall-back":{"error":"Erreur"}},"get-custom-operators":{"custom-operators":{"label":{"macros":"Macros"}}},"make-render-column":{"render-column":{"aria-label-group-by":"Regrouper par","title-remove-group-by-column":"Supprimer le groupe par colonne"}},"order-by-row":{"aria-label-order-by":"Trier par","label-limit":"Limiter","label-offset":"Décalage","label-order-by":"Trier par"},"preview":{"label-element":{"preview":"Aperçu","tooltip-copy-to-clipboard":"Copier dans le presse-papiers"}},"query-header":{"content-invalid-query":"","editor-modes":{"label-builder":"Builder","label-code":"Code"},"label-dataset":"Ensemble de données","label-filter":"Filtrer","label-format":"Format","label-group":"Groupe","label-order":"Ordonner","label-preview":"Aperçu","label-table":"Tableau","placeholder-select-format":"Sélectionner le format","run-query":"Exécuter la requête"},"query-meta":{"variables":{"textField":"","valueField":""}},"query-toolbox":{"content-hit-ctrlcmdreturn-to-run-query":"Appuyer sur CTRL/CMD+Retour pour exécuter la requête","tooltip-collapse":"Réduire l’éditeur","tooltip-expand":"Développer l’éditeur","tooltip-format-query":"Requête de format"},"query-validator":{"query-will-process":"","validating-query":"Validation de la requête..."},"raw-editor":{"render-placeholder":{"editing-in-expanded-code-editor":"Modification dans l’éditeur de code développé"},"title-query-num":"Requête {{queryNum}}"},"select-column":{"label-column":"Colonne"},"select-custom-function-parameters":{"aria-label-parameter":"Paramètre {{index}} pour la colonne {{columnIndex}}","render-parameters":{"params":{"title-remove-parameter":"Supprimer le paramètre"}},"title-add-parameter":"Ajouter un paramètre"},"select-row":{"aggregate-options":{"options":{"label":{"aggregations":"Agrégations","macros":"Macros"}}},"label":{"time":"temps","value":"valeur"},"label-alias":"Pseudonyme","label-data-operations":"Opérations de données","title-add-column":"Ajouter une colonne","title-remove-column":"Supprimer la colonne"},"settings":{"aria-label-conjunction":"Conjonction","aria-label-field":"Champ","aria-label-operator":"Opérateur","title-button-filter":"Filtre {{ buttonLabel }}"},"sql-query-editor-lazy":{"text-loading-editor":"Chargement de l\'éditeur"},"table-selector":{"aria-label-table-selector":"Sélecteur de tableaux","placeholder-loading":"Chargement des tableaux","placeholder-select-table":"Sélectionner un tableau"},"tlssecrets-config":{"content-tlsssl-client-certificate":"Pour vous authentifier avec un certificat client TLS/SSL, fournissez le certificat client ici.","content-tlsssl-client-key":"Pour vous authentifier avec un certificat TLS/SSL client, fournissez la clé ici.","content-tlsssl-root-certificate":"Si le mode TLS/SSL sélectionné nécessite un certificat racine de serveur, fournissez-le ici","tlsssl-client-certificate":"Certificat client TLS/SSL","tlsssl-client-key":"Clé client TLS/SSL","tlsssl-root-certificate":"Certificat racine TLS/SSL"},"visual-editor":{"label-filter-by-column-value":"Filtrer par valeur de colonne","label-group-by-column":"Grouper par colonne"},"widgets":{"aria-label-macros-value-selector":"Sélecteur de valeur de macros"}},"utils":{"get-columns-width-indices":{"label-selected-columns":"Colonnes sélectionnées"}}}}')}}]);