import { __exports as markRole } from '../../../../../../_virtual/markRole.js';

var hasRequiredMarkRole;

function requireMarkRole () {
	if (hasRequiredMarkRole) return markRole;
	hasRequiredMarkRole = 1;

	Object.defineProperty(markRole, "__esModule", {
	  value: true
	});
	markRole.default = undefined;
	var markRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['prohibited'],
	  prohibitedProps: [],
	  props: {
	    'aria-braillelabel': null,
	    'aria-brailleroledescription': null,
	    'aria-description': null
	  },
	  relatedConcepts: [{
	    concept: {
	      name: 'mark'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = markRole$1;
	markRole.default = _default;
	return markRole;
}

export { requireMarkRole as __require };
//# sourceMappingURL=markRole.js.map
