"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[7626],{7626(e){e.exports=JSON.parse(`{"grafana-sql":{"components":{"confirm-modal":{"builder-mode":"Le mode Cr\xE9ateur n\u2019affiche pas les modifications apport\xE9es au code. Le cr\xE9ateur de requ\xEAtes affichera les derni\xE8res modifications que vous avez apport\xE9es en mode Cr\xE9ateur.","cancel":"Annuler","clipboard":"Voulez-vous copier votre code dans le presse-papiers\xA0?","copy-code-and-switch":"Copier le code et changer","discard-code-and-switch":"Ignorer le code et changer","warning":"Avertissement"},"connection-limits":{"auto-max-idle":"Inactivit\xE9 maximale automatique","content-auto-max-idle":"","content-max-idle":"","content-max-lifetime":"La dur\xE9e maximale en secondes pendant laquelle une connexion peut \xEAtre r\xE9utilis\xE9e. Si la valeur est\xA00, les connexions sont r\xE9utilis\xE9es pour toujours.","content-max-open":"","max-idle":"Inactivit\xE9 maximale","max-lifetime":"Dur\xE9e de vie maximale","max-open":"Ouverture maximale","title-connection-limits":"Limites de connexion"},"dataset-selector":{"aria-label-dataset-selector":"S\xE9lecteur d\u2019ensemble de donn\xE9es"},"error-boundary":{"fall-back":{"error":"Erreur"}},"get-custom-operators":{"custom-operators":{"label":{"macros":"Macros"}}},"make-render-column":{"render-column":{"aria-label-group-by":"Regrouper par","title-remove-group-by-column":"Supprimer le groupe par colonne"}},"order-by-row":{"aria-label-order-by":"Trier par","label-limit":"Limiter","label-offset":"D\xE9calage","label-order-by":"Trier par"},"preview":{"label-element":{"preview":"Aper\xE7u","tooltip-copy-to-clipboard":"Copier dans le presse-papiers"}},"query-header":{"content-invalid-query":"","editor-modes":{"label-builder":"Builder","label-code":"Code"},"label-dataset":"Ensemble de donn\xE9es","label-filter":"Filtrer","label-format":"Format","label-group":"Groupe","label-order":"Ordonner","label-preview":"Aper\xE7u","label-table":"Tableau","placeholder-select-format":"S\xE9lectionner le format","run-query":"Ex\xE9cuter la requ\xEAte"},"query-meta":{"variables":{"textField":"","valueField":""}},"query-toolbox":{"content-hit-ctrlcmdreturn-to-run-query":"Appuyer sur CTRL/CMD+Retour pour ex\xE9cuter la requ\xEAte","tooltip-collapse":"R\xE9duire l\u2019\xE9diteur","tooltip-expand":"D\xE9velopper l\u2019\xE9diteur","tooltip-format-query":"Requ\xEAte de format"},"query-validator":{"query-will-process":"","validating-query":"Validation de la requ\xEAte..."},"raw-editor":{"render-placeholder":{"editing-in-expanded-code-editor":"Modification dans l\u2019\xE9diteur de code d\xE9velopp\xE9"},"title-query-num":"Requ\xEAte {{queryNum}}"},"select-column":{"label-column":"Colonne"},"select-custom-function-parameters":{"aria-label-parameter":"Param\xE8tre {{index}} pour la colonne {{columnIndex}}","render-parameters":{"params":{"title-remove-parameter":"Supprimer le param\xE8tre"}},"title-add-parameter":"Ajouter un param\xE8tre"},"select-row":{"aggregate-options":{"options":{"label":{"aggregations":"Agr\xE9gations","macros":"Macros"}}},"label":{"time":"temps","value":"valeur"},"label-alias":"Pseudonyme","label-data-operations":"Op\xE9rations de donn\xE9es","title-add-column":"Ajouter une colonne","title-remove-column":"Supprimer la colonne"},"settings":{"aria-label-conjunction":"Conjonction","aria-label-field":"Champ","aria-label-operator":"Op\xE9rateur","title-button-filter":"Filtre {{ buttonLabel }}"},"sql-query-editor-lazy":{"text-loading-editor":"Chargement de l'\xE9diteur"},"table-selector":{"aria-label-table-selector":"S\xE9lecteur de tableaux","placeholder-loading":"Chargement des tableaux","placeholder-select-table":"S\xE9lectionner un tableau"},"tlssecrets-config":{"content-tlsssl-client-certificate":"Pour vous authentifier avec un certificat client TLS/SSL, fournissez le certificat client ici.","content-tlsssl-client-key":"Pour vous authentifier avec un certificat TLS/SSL client, fournissez la cl\xE9 ici.","content-tlsssl-root-certificate":"Si le mode TLS/SSL s\xE9lectionn\xE9 n\xE9cessite un certificat racine de serveur, fournissez-le ici","tlsssl-client-certificate":"Certificat client TLS/SSL","tlsssl-client-key":"Cl\xE9 client TLS/SSL","tlsssl-root-certificate":"Certificat racine TLS/SSL"},"visual-editor":{"label-filter-by-column-value":"Filtrer par valeur de colonne","label-group-by-column":"Grouper par colonne"},"widgets":{"aria-label-macros-value-selector":"S\xE9lecteur de valeur de macros"}},"utils":{"get-columns-width-indices":{"label-selected-columns":"Colonnes s\xE9lectionn\xE9es"}}}}`)}}]);

//# sourceMappingURL=7626.77c314c84065c30e5ae6.js.map