import { __exports as listRole } from '../../../../../../_virtual/listRole.js';

var hasRequiredListRole;

function requireListRole () {
	if (hasRequiredListRole) return listRole;
	hasRequiredListRole = 1;

	Object.defineProperty(listRole, "__esModule", {
	  value: true
	});
	listRole.default = undefined;
	var listRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {},
	  relatedConcepts: [{
	    concept: {
	      name: 'menu'
	    },
	    module: 'HTML'
	  }, {
	    concept: {
	      name: 'ol'
	    },
	    module: 'HTML'
	  }, {
	    concept: {
	      name: 'ul'
	    },
	    module: 'HTML'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [['listitem']],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = listRole$1;
	listRole.default = _default;
	return listRole;
}

export { requireListRole as __require };
//# sourceMappingURL=listRole.js.map
